@@ -23,13 +23,13 @@
 #include <tqvaluevector.h>
 
 class K3bProcess;
-class KProcess;
+class TDEProcess;
 
 
 class K3bAudioNormalizeJob : public K3bJob
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bAudioNormalizeJob( K3bJobHandler*, TQObject* parent = 0, const char* name = 0 );
@@ -43,7 +43,7 @@ class K3bAudioNormalizeJob : public K3bJob
 
  private slots:
   void slotStdLine( const TQString& line );
-  void slotProcessExited( KProcess* p );
+  void slotProcessExited( TDEProcess* p );
 
  private:
   K3bProcess* m_process;
