@@ -29,7 +29,9 @@ class K3bFileItem;
 class TQTextStream;
 class K3bProcess;
 class TDEProcess;
-class K3bDevice::Device;
+namespace K3bDevice {
+    class Device;
+}
 class KTempFile;
 
 
