@@ -25,7 +25,9 @@
 class K3bExternalBin;
 class K3bProcess;
 class TDEProcess;
-class K3bDevice::Device;
+namespace K3bDevice {
+    class Device;
+}
 
 
 class K3bCdrecordWriter : public K3bAbstractWriter
