@@ -20,7 +20,9 @@
 #include <k3bjob.h>
 
 class K3bMovixDoc;
-class K3bDevice::Device;
+namespace K3bDevice {
+    class Device;
+}
 class K3bDataJob;
 class KTempFile;
 class K3bMovixInstallation;
