@@ -13,12 +13,12 @@
 * See the file "COPYING" for the exact licensing terms.
 */
 
-#include <klocale.h>
-#include <kconfig.h>
+#include <tdelocale.h>
+#include <tdeconfig.h>
 #include <kstandarddirs.h>
 #include <kurl.h>
-#include <ktempfile.h>
-#include <kio/global.h>
+#include <tdetempfile.h>
+#include <tdeio/global.h>
 
 #include <tqstring.h>
 #include <tqdatetime.h>
@@ -225,11 +225,11 @@ void K3bVcdJob::vcdxBuild()
 
     *m_process << TQString( "%1" ).arg( TQFile::encodeName( m_xmlFile ).data() );
 
-    connect( m_process, TQT_SIGNAL( receivedStderr( KProcess*, char*, int ) ),
-             this, TQT_SLOT( slotParseVcdxBuildOutput( KProcess*, char*, int ) ) );
-    connect( m_process, TQT_SIGNAL( receivedStdout( KProcess*, char*, int ) ),
-             this, TQT_SLOT( slotParseVcdxBuildOutput( KProcess*, char*, int ) ) );
-    connect( m_process, TQT_SIGNAL( processExited( KProcess* ) ),
+    connect( m_process, TQT_SIGNAL( receivedStderr( TDEProcess*, char*, int ) ),
+             this, TQT_SLOT( slotParseVcdxBuildOutput( TDEProcess*, char*, int ) ) );
+    connect( m_process, TQT_SIGNAL( receivedStdout( TDEProcess*, char*, int ) ),
+             this, TQT_SLOT( slotParseVcdxBuildOutput( TDEProcess*, char*, int ) ) );
+    connect( m_process, TQT_SIGNAL( processExited( TDEProcess* ) ),
              this, TQT_SLOT( slotVcdxBuildFinished() ) );
 
     // vcdxbuild commandline parameters
@@ -243,7 +243,7 @@ void K3bVcdJob::vcdxBuild()
     kdDebug() << s << flush << endl;
     emit debuggingOutput( "vcdxbuild command:", s );
 
-    if ( !m_process->start( KProcess::NotifyOnExit, KProcess::AllOutput ) ) {
+    if ( !m_process->start( TDEProcess::NotifyOnExit, TDEProcess::AllOutput ) ) {
         kdDebug() << "(K3bVcdJob) could not start vcdxbuild" << endl;
         emit infoMessage( i18n( "Could not start %1." ).arg( "vcdxbuild" ), K3bJob::ERROR );
         cancelAll();
@@ -251,7 +251,7 @@ void K3bVcdJob::vcdxBuild()
     }
 }
 
-void K3bVcdJob::slotParseVcdxBuildOutput( KProcess*, char* output, int len )
+void K3bVcdJob::slotParseVcdxBuildOutput( TDEProcess*, char* output, int len )
 {
     TQString buffer = TQString::fromLocal8Bit( output, len );
 
@@ -558,7 +558,7 @@ TQString K3bVcdJob::jobDetails() const
 {
     return ( i18n( "1 MPEG (%1)",
                    "%n MPEGs (%1)",
-                   m_doc->tracks() ->count() ).arg( KIO::convertSize( m_doc->size() ) )
+                   m_doc->tracks() ->count() ).arg( TDEIO::convertSize( m_doc->size() ) )
              + ( m_doc->copies() > 1
                  ? i18n( " - %n copy", " - %n copies", m_doc->copies() )
                  : TQString() ) );
