@@ -18,7 +18,7 @@
 
 #include <k3bdvddoc.h>
 #include "k3b_export.h"
-class KConfig;
+class TDEConfig;
 
 class LIBK3B_EXPORT K3bVideoDvdDoc : public K3bDvdDoc
 {
