@@ -20,13 +20,13 @@
 #include <tqcombobox.h>
 
 
-class KConfigBase;
+class TDEConfigBase;
 
 
 class K3bDataModeWidget : public TQComboBox
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bDataModeWidget( TQWidget* parent = 0, const char* name = 0 );
@@ -37,8 +37,8 @@ class K3bDataModeWidget : public TQComboBox
    */
   int dataMode() const;
 
-  void saveConfig( KConfigBase* );
-  void loadConfig( KConfigBase* );
+  void saveConfig( TDEConfigBase* );
+  void loadConfig( TDEConfigBase* );
 
  public slots:
   void setDataMode( int );
