@@ -19,13 +19,13 @@
 #include <tqcombobox.h>
 #include <k3bdatadoc.h>
 
-class KConfigBase;
+class TDEConfigBase;
 
 
 class K3bDataMultiSessionCombobox : public TQComboBox
 {
   Q_OBJECT
-  TQ_OBJECT
+  
 
  public:
   K3bDataMultiSessionCombobox( TQWidget* parent = 0, const char* name = 0 );
@@ -38,8 +38,8 @@ class K3bDataMultiSessionCombobox : public TQComboBox
 
   void setForceNoMultisession( bool );
 
-  void saveConfig( KConfigBase* );
-  void loadConfig( KConfigBase* );
+  void saveConfig( TDEConfigBase* );
+  void loadConfig( TDEConfigBase* );
 
  public slots:
   void setMultiSessionMode( K3bDataDoc::MultiSessionMode );
